==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/ENERGYSTARCUSTOMERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ENERGYSTARCUSTOMERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ENERGYSTARCUSTOMERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ENERGYSTARCUSTOMER" type="{http://schemas.datastream.net/MP_fields}CODE100_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYSTARCUSTOMERID_Type", propOrder = {
    "energystarcustomer"
})
public class ENERGYSTARCUSTOMERID_Type {

    @XmlElement(name = "ENERGYSTARCUSTOMER", required = true)
    protected String energystarcustomer;

    /**
     * Obtient la valeur de la propriété energystarcustomer.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARCUSTOMER() {
        return energystarcustomer;
    }

    /**
     * Définit la valeur de la propriété energystarcustomer.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARCUSTOMER(String value) {
        this.energystarcustomer = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/ENERGYSTARCUSTOMERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ENERGYSTARCUSTOMERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ENERGYSTARCUSTOMERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ENERGYSTARCUSTOMER" type="{http://schemas.datastream.net/MP_fields}CODE100_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYSTARCUSTOMERID_Type", propOrder = {
    "energystarcustomer"
})
public class ENERGYSTARCUSTOMERID_Type {

    @XmlElement(name = "ENERGYSTARCUSTOMER", required = true)
    protected String energystarcustomer;

    /**
     * Gets the value of the energystarcustomer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARCUSTOMER() {
        return energystarcustomer;
    }

    /**
     * Sets the value of the energystarcustomer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARCUSTOMER(String value) {
        this.energystarcustomer = value;
    }

}
